@@ -1,12 +1,16 @@
-import requests, json, sseclient, rx
-from rx.scheduler import NewThreadScheduler
+import json
+import requests
+
+import rx
 import rx.operators as ops
+import sseclient
+from rx.scheduler import NewThreadScheduler
 
 scheduler = NewThreadScheduler()
 
 
 class MagixHttpClient:
-    """Waltz-Controls Magix client based on HTTP transport
+    """Waltz-Controls Magix client based on HTTP transport. This client's API is described in Waltz-Controls RFC-2
 
     Example:
         >>> client = MagixHttpClient(magix_host)#http://localhost:8080 by default
@@ -26,10 +30,11 @@ class MagixHttpClient:
         )
         self.stream.connect()
 
-    def broadcast(self, message):
+    def broadcast(self, message, channel='message'):
         encoded_message = json.dumps(message).encode('utf-8')
         # TODO fire and forget
-        requests.post(self.magix_broadcast, data=encoded_message, headers={'Content-Type': 'application/json'})
+        requests.post(self.magix_broadcast, data=encoded_message, headers={'Content-Type': 'application/json'},
+                      params={'channel': channel})
         pass
 
     def observe(self, channel='message'):
