@@ -1,15 +1,6 @@
 import json
 
 
-def toMessage(dict):
-    return Message(id=dict["id"], origin=dict["origin"], parentId=dict["parentId"], target=dict["target"],
-                   user=dict["user"], action=dict["action"], payload=dict["payload"])
-
-
-def fromJson(jsonStr):
-    return json.loads(jsonStr, object_hook=toMessage)
-
-
 class Message:
     """Waltz-Controls Message as defined in RFC-1
     """
@@ -23,3 +14,11 @@ class Message:
         self.user = user
         self.action = action
         self.payload = payload
+
+    @classmethod
+    def from_json(cls, data, payload_cls=None):
+        result = json.loads(data)
+        payload = result.get('payload')
+        if payload and payload_cls:
+            result['payload'] = payload_cls(**payload)
+        return Message(**result)
